@@ -3,6 +3,9 @@
 # The author, Jim Avera (jim.avera at gmail) has waived all copyright and
 # related or neighboring rights to the content of this file.
 # Attribution is requested but is not required.
+#
+# PLEASE NOTE that the above applies to THIS FILE ONLY.  Other files in the
+# same distribution or other collection may have more restrictive terms.
 
 # Common setup stuff, not specifically for test cases.
 # This file is intended to be identical in all my module distributions.
@@ -26,25 +29,31 @@ our @EXPORT_OK = qw/oops btw btwN/;
 use Import::Into;
 use Carp;
 
-sub oops(@) { 
+sub oops(@) {
   my $pkg = caller;
-  my $pfx = "\n"; 
-  $pfx .= "$pkg " if $pkg ne 'main';
-  $pfx .= "oops:\n";
-  @_ = ($pfx, @_, "\n");
+  my $pfx = "\noops";
+  $pfx .= " in pkg '$pkg'" unless $pkg eq 'main';
+  $pfx .= ":\n";
+  if (defined(&Spreadsheet::Edit::logmsg)) {
+    # Show current apply sheet & row if any.
+    @_=($pfx, &Spreadsheet::Edit::logmsg(@_));
+  } else {
+    @_=($pfx, @_);
+  }
+  push @_,"\n" unless $_[-1] =~ /\R\z/;
   goto &Carp::confess
 }
 
 # "By The Way" messages showing file:linenum of the call
 sub btw(@) { unshift @_,0; goto &btwN }
-sub btwN($@) { 
-  my $N=shift; 
+sub btwN($@) {
+  my $N=shift;
   my ($fn, $lno) = (caller($N))[1,2];
-  $fn =~ s/.*[\\\/]//;  
+  $fn =~ s/.*[\\\/]//;
   $fn =~ s/(.)\.[a-z]+$/$1/a;
-  local $_ = join("",@_); 
-  s/\n\z//s; 
-  printf "%s:%d: %s\n", $fn, $lno, $_;
+  local $_ = join("",@_);
+  s/\n\z//s;
+  printf STDERR "%s:%d: %s\n", $fn, $lno, $_;
 }
 
 sub import {
@@ -142,7 +151,7 @@ sub import {
   require Guard;
   Guard->import::into($target, qw(scope_guard guard));
 
-  use Data::Dumper::Interp 6.003 (); # 6.003 fixed AUTOLOAD $@ corruption
+  use Data::Dumper::Interp 6.006 ();
   unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
     # unless we are testing DDI
     Data::Dumper::Interp->import::into($target,
